@@ -58,7 +58,7 @@ class Signal:
     users know the semantics of the timeseries and feeds. 
 
     Signals have periods ("ticks") - but these may be implicit, e.g. if
-    using the `infer_freq` method of pandas DatetimeIndex
+    using the `infer_freq` method of pandas DatetimeIndex.
 
     """
     def __init__(self, name, metadata=None, timeseries_df=None, feeds_df=None, ts_column='count'):
@@ -66,9 +66,24 @@ class Signal:
         if metadata is None:
             metadata = dict()
         self.metadata = metadata
+
+        if timeseries_df is not None:
+            if type(timeseries_df) is pd.Series:
+                timeseries_df = timeseries_df.to_frame(name=name)
+                ts_column = name
+            self.assert_df_index_type(timeseries_df)
+        
+        if feeds_df is not None:
+            self.assert_df_index_type(feeds_df)
+            
         self.timeseries_df=timeseries_df
         self.feeds_df=feeds_df
         self.ts_column = ts_column
+    
+    @staticmethod
+    def assert_df_index_type(df):
+        assert str(df.index.dtype) == 'datetime64[ns, UTC]', \
+            'we expect dataframes with timezone-aware index dtypes in UTC timezone'
 
     @abstractmethod
     def __call__(self, start, end, freq='D'):
@@ -356,7 +371,7 @@ class Signal:
             return getattr(self.timeseries_df, name)
         except AttributeError as e:
             raise AttributeError(
-                f"type object '{self.type}' has no attribute '{name}'"
+                f"type object '{type(self)}' has no attribute '{name}'"
             )
     
     def __getitem__(self, subscript):
@@ -410,8 +425,9 @@ class Signal:
         signals_dir = Path(signals_path)
         static_config_paths = signals_dir.glob('*.static_fields.json')
         signals = []
-        for signal_config_path in static_config_paths:            
-            signal_config = json.load(open(signal_config_path))
+        for signal_config_path in static_config_paths:
+            with open(signal_config_path) as f:
+                signal_config = json.load(f)
             signal_id = str(signal_config_path.name).split('.')[0]
             # load signal dataframes from parquet files
             df_paths = [p.name for p in signals_dir.glob(f'{signal_id}.*.parquet')]
@@ -465,14 +481,10 @@ class DataframeSignal(Signal):
         timeseries_df, metadata=None,
         feeds_df=None, ts_column='count'
     ):
-        super().__init__(name, metadata=metadata, timeseries_df=timeseries_df, feeds_df=feeds_df, ts_column=ts_column)
-        if type(timeseries_df) is pd.Series:
-            timeseries_df = timeseries_df.to_frame(name=name)
-            ts_column = name
-        assert str(timeseries_df.index.dtype) == 'datetime64[ns, UTC]', \
-            'we expect dataframes with timezone-aware index dtypes in UTC timezone'
-        self.timeseries_df = timeseries_df
-        self.ts_column = ts_column
+        super().__init__(
+            name,
+            metadata=metadata, timeseries_df=timeseries_df, feeds_df=feeds_df, ts_column=ts_column
+        )
 
     def to_dict(self):
         return {
@@ -621,7 +633,7 @@ class AylienSignal(Signal):
         else:
             raise UnknownFrequencyArgument
 
-    def update(self, start=None, end=None, freq='D'):
+    def update(self, start=None, end=None, freq='D', ts_endpoint=None):
         """
         This method should eventually update all of the data in the signal, not just 
         the timeseries_df. This is a work in progress.
@@ -630,7 +642,7 @@ class AylienSignal(Signal):
         any new data while retaining the existing information as well
         :param start: datetime
         :param end: datetime
-        """
+        """        
         if end is None:
             end = self.normalize_timestamp(datetime.datetime.now(), freq)
         # if start is None, we look up to 30 days ago
@@ -649,6 +661,8 @@ class AylienSignal(Signal):
                     f'end date was more than 30 days ago, so we are using '
                     f'default update interval of 30 days --> {start} to {end}'
                 )
+        if ts_endpoint is None:
+            ts_endpoint = self.ts_endpoint
 
         # first check if we already have this time range,
         # if so, we don't need to query again
@@ -670,7 +684,7 @@ class AylienSignal(Signal):
                         start = dt
                         break
             period = self.pd_freq_to_aylien_period(freq)
-            aylien_ts_df = self.query_news_signals(start, end, period)
+            aylien_ts_df = self.query_news_signals(start, end, period, ts_endpoint)
             if self.timeseries_df is None:
                 self.timeseries_df = aylien_ts_df
             else:
@@ -688,9 +702,14 @@ class AylienSignal(Signal):
         params['aql'] = self.aql
         return params
 
-    def query_news_signals(self, start, end, period):
+    def query_news_signals(self, start, end, period, ts_endpoint=None):
+        if ts_endpoint is None:
+            ts_endpoint = self.ts_endpoint
         params = self.make_query(start, end, period=period)
-        aylien_ts = self.ts_endpoint(params)
+        if ts_endpoint != self.ts_endpoint:
+            print("PARAMS")
+            print(params)
+        aylien_ts = ts_endpoint(params)
         ts_df = aylien_ts_to_df(
             aylien_ts, dt_index=True
         )
@@ -725,6 +744,7 @@ class AylienSignal(Signal):
             start_end_tups = [(s, e) for s, e in zip(list(date_range), list(date_range)[1:])]
             story_bucket_records = []
             for start, end in tqdm.tqdm(start_end_tups):
+                logger.info(f'Getting stories for {start} to {end}')
                 params = self.make_query(start, end)
                 stories = self.stories_endpoint(params)
                 story_bucket_records.append({'timestamp': start, 'stories': stories})
@@ -884,12 +904,13 @@ class AggregateSignal(Signal):
         end = reference_index.max()
         return start, end, freq
 
-    def plot(self):
+    def plot(self, include_aggregate=False):
         if len(self.components) and getattr(self.components[0], 'timeseries_df', None) is not None:
             start, end, freq = self.infer_index_args()
             df = self.components_to_df(start, end, freq=freq)
             agg = self(start, end, freq=freq)
-            df = pd.concat([df, agg.timeseries_df], axis=1)
+            if include_aggregate:
+                df = pd.concat([df, agg.timeseries_df], axis=1)
             plot = df.plot()
             return plot
         else:
@@ -913,7 +934,7 @@ class AggregateSignal(Signal):
             return getattr(self.df, name)
         except AttributeError as _:
             raise AttributeError(
-                f"type object '{self.type}' has no attribute '{name}'"
+                f"type object '{type(self)}' has no attribute '{name}'"
             )
 
 
